%ifarch %arm
# armv7hl build nodes run out of memory while building 4 C++ files from this package at once
%define threads 1
%else
%ifarch aarch64
# limit parallel builds to 4 on aarch64
%define threads 4
%else
# number of CPUs if defined, else 1
%define threads %(echo 1%{?_smp_mflags} | sed -e 's/1-j//')
%endif
%endif

# TODO: Fix underlinking issues
%define _disable_ld_no_undefined 1

%define _python_bytecompile_errors_terminate_build 0
%global _legacy_common_support 1

Name:           panda3d
Version:        1.10.7
Release:        %mkrel 1
Summary:        Game engine for Python and C++ 3D games
Group:          Development/Tools
License:        BSD
URL:            https://www.panda3d.org
Source0:        https://www.panda3d.org/download/%{name}-%{version}/%{name}-%{version}.tar.gz
Patch0:         panda3d-1.10.1-mga-sysconfdir.patch

BuildRequires:  bison
BuildRequires:  flex
#BuildRequires:  pkgconfig(bullet)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(libtiff-4)
#BuildRequires:  pkgconfig(ode)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xxf86dga)
BuildRequires:  pkgconfig(zlib)

%description
Panda3D is a game engine, a framework for 3D rendering and game development
for Python and C++ programs. Panda3D is Open Source and free for any purpose,
including commercial ventures, thanks to its liberal revised BSD license.

%prep
%autosetup -p1

%build
%set_build_flags
# (akien) getting an error with ODE library, needs investigation
# ImportError: built/lib/libpandaode.so.1.9: undefined symbol: dBodyGetNumJoints
# (akien) Not compatible with bullet 3, disabling for now.
%{__python3} makepanda/makepanda.py \
    --distributor "%{_vendor}" --threads %{threads} --verbose \
    --everything --no-egl --no-gles --no-gles2 --no-opencv --no-ode --no-bullet

%install
%{__python3} makepanda/installpanda.py \
    --destdir %{buildroot} --prefix %{_prefix}
pathfix.py -pni "%{__python3} %{py3_shbang_opts}" %{buildroot}%{_datadir}/%{name}

%files
%{_bindir}/*
%{_datadir}/%{name}/
%{_datadir}/application-registry/%{name}.applications
%{_datadir}/applications/pview.desktop
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/mime-info/%{name}.{keys,mime}
%{_libdir}/%{name}/
%{_includedir}/%{name}/
%dir %{_sysconfdir}/%{name}
%config %{_sysconfdir}/%{name}/Confauto.prc
%config(noreplace) %{_sysconfdir}/%{name}/Config.prc
%{_sysconfdir}/ld.so.conf.d/%{name}.conf
%{python3_sitearch}/%{name}/
%{python3_sitearch}/%{name}.dist-info/
%{python3_sitelib}/%{name}.pth


%changelog
* Thu Dec 17 2020 akien <akien> 1.10.7-1.mga8
+ Revision: 1660141
- Rebuild without bullet support
- Version 1.10.7
- Rebuild for bullet 3.06

* Thu Aug 20 2020 joequant <joequant> 1.10.6-1.mga8
+ Revision: 1617032
- fix build requires
- add shebangs to python3
- update to 1.10.6 to fix build
- fix build
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags
+ daviddavid <daviddavid>
- rebuild for python3.8

* Tue Mar 12 2019 akien <akien> 1.10.2-1.mga7
+ Revision: 1374396
- Version 1.10.2

* Mon Mar 04 2019 akien <akien> 1.10.1-1.mga7
+ Revision: 1371547
- Version 1.10.1
- Switch to Python 3
- Rebuild for bullet 2.88

* Mon Oct 29 2018 wally <wally> 1.9.4-8.mga7
+ Revision: 1326527
- limit parallel builds to 4 on aarch64

* Sun Sep 23 2018 umeabot <umeabot> 1.9.4-7.mga7
+ Revision: 1300102
- Mageia 7 Mass Rebuild

* Tue Jul 24 2018 wally <wally> 1.9.4-6.mga7
+ Revision: 1245059
- add patch for aarch64 support

* Mon Jan 29 2018 daviddavid <daviddavid> 1.9.4-5.mga7
+ Revision: 1197920
- rebuild for new bullet 2.87

* Thu Sep 07 2017 cjw <cjw> 1.9.4-3.mga7
+ Revision: 1151735
- add some changes from upstream git to fix build with openssl 1.1

* Mon Jul 03 2017 pterjan <pterjan> 1.9.4-2.mga6
+ Revision: 1109035
- Only build one file at once on arm

* Mon Jul 03 2017 akien <akien> 1.9.4-1.mga6
+ Revision: 1109011
- Disable ODE integration for now, triggers build failure
- imported package panda3d

